==> apache-kylin-3.1.3-source-release.zip: apache-kylin-3.1.3/core-common/src/test/java/org/apache/kylin/common/util/EncryptUtilTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
*/

package org.apache.kylin.common.util;

import org.junit.After;
import org.junit.Assert;
import org.junit.Before;
import org.junit.Test;

public class EncryptUtilTest extends LocalFileMetadataTestCase {
    @Before
    public void setUp() throws Exception {
        this.createTestMetadata();
    }

    @After
    public void after() throws Exception {
        this.cleanupTestMetadata();
    }

    @Test
    public void testAESEncrypt(){
        String input = "hello world";
        String result1 = EncryptUtil.encrypt(input);
        String decrypt1 = EncryptUtil.decrypt(result1);
        Assert.assertEquals(input, decrypt1);
        String result2 = EncryptUtil.encrypt(input);
        Assert.assertEquals(result2, result1);

        input = "this is a long string #&$";
        result1 = EncryptUtil.encrypt(input);
        decrypt1 = EncryptUtil.decrypt(result1);
        Assert.assertEquals(input, decrypt1);
        result2 = EncryptUtil.encrypt(input);
        Assert.assertEquals(result2, result1);


    }

    @Test
    public void testNullInput() {
        Assert.assertNull(EncryptUtil.encrypt(null));
        Assert.assertNull(EncryptUtil.decrypt(null));
    }

}

==> apache-kylin-4.0.0-source-release.zip: apache-kylin-4.0.0/core-common/src/test/java/org/apache/kylin/common/util/EncryptUtilTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
*/

package org.apache.kylin.common.util;

import org.junit.Assert;
import org.junit.Test;

public class EncryptUtilTest {

    @Test
    public void testAESEncrypt(){
        String input = "hello world";
        String result1 = EncryptUtil.encrypt(input);
        String decrypt1 = EncryptUtil.decrypt(result1);
        Assert.assertEquals(input, decrypt1);
        String result2 = EncryptUtil.encrypt(input);
        Assert.assertEquals(result2, result1);

        input = "this is a long string #&$";
        result1 = EncryptUtil.encrypt(input);
        decrypt1 = EncryptUtil.decrypt(result1);
        Assert.assertEquals(input, decrypt1);
        result2 = EncryptUtil.encrypt(input);
        Assert.assertEquals(result2, result1);


    }

    @Test
    public void testNullInput() {
        Assert.assertNull(EncryptUtil.encrypt(null));
        Assert.assertNull(EncryptUtil.decrypt(null));
    }

}
